@@ -1,5 +1,5 @@
 from schematics.models import Model, ValidationError
-from schematics.types import ListType, ModelType, UUIDType, URLType, StringType, DictType, IntType, FloatType, UnionType
+from schematics.types import UUIDType, URLType, StringType, DictType, IntType, FloatType, UnionType, BooleanType
 
 
 class TaskDataEntry(Model):
@@ -10,18 +10,24 @@ class TaskDataEntry(Model):
       {
         "task_key": "407fdd93-687a-46bb-b578-89eb96b4109d",
         "datapoint_uri": "https://domain.com/file1.jpg",
+        "datapoint_text": "",
+        "is_text_question": False,
         "datapoint_hash": "f4acbe8562907183a484498ba901bfe5c5503aaa"
       },
       {
         "task_key": "20bd4f3e-4518-4602-b67a-1d8dfabcce0c",
-        "datapoint_uri": "https://domain.com/file2.jpg",
+        "datapoint_uri": "",
+        "datapoint_text": "any question here",
+        "is_text_question": True,
         "datapoint_hash": "f4acbe8562907183a484498ba901bfe5c5503aaa"
       }
     ]
     """
     task_key = UUIDType()
-    datapoint_uri = URLType(required=True, min_length=10)
+    datapoint_uri = URLType()
+    datapoint_text = DictType(StringType)
     datapoint_hash = StringType()
+    is_text_question = BooleanType()
     metadata = DictType(
       UnionType([
         StringType(required=False, max_length=256),
@@ -35,6 +41,19 @@ class TaskDataEntry(Model):
             raise ValidationError("metadata should be < 1024")
         return value
 
+    def validate_datapoint_text(self, data, value):
+        if data.get('is_text_question') and not value:
+            raise ValidationError("datapoint_text is missing.")
+        return value
+
+    def validate_datapoint_uri(self, data, value):
+        if not data.get('is_text_question'):
+            if not value:
+                raise ValidationError("datapoint_uri is missing.")
+            if len(value) < 10:
+                raise ValidationError("datapoint_uri length is less than 10")
+        return value
+
 
 def validate_taskdata_entry(value: dict):
     """ Validate taskdata entry """
