@@ -63,8 +63,23 @@ class Webhook(Model):
 class TaskData(Model):
     """ objects within taskdata list in Manifest """
     task_key = UUIDType(required=True)
-    datapoint_uri = URLType(required=True, min_length=10)
+    datapoint_uri = URLType()
     datapoint_hash = StringType(required=True, min_length=10)
+    datapoint_text = DictType(StringType)
+    is_text_question = BooleanType()
+
+    def validate_datapoint_text(self, data, value):
+        if data.get('is_text_question') and not value:
+            raise ValidationError("datapoint_text is missing.")
+        return value
+
+    def validate_datapoint_uri(self, data, value):
+        if not data.get('is_text_question'):
+            if not value:
+                raise ValidationError("datapoint_uri is missing.")
+            if len(value) < 10:
+                raise ValidationError("datapoint_uri length is less than 10")
+        return value
 
 
 class RequestConfig(Model):
